"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.JsImpl = void 0;
const logic_base_1 = require("@devacour/logic-base");
const vm2_1 = require("vm2");
const jsGuard_1 = require("./jsGuard");
function JsImpl({ VM = (context) => new vm2_1.VM({
    compiler: 'javascript',
    timeout: 500,
    eval: false,
    sandbox: { ...context },
}), ...config } = {}) {
    return {
        boolean(evaluation) {
            try {
                const instance = VM(evaluation.context);
                const value = instance.run(evaluation.source.value);
                if (typeof value !== 'boolean') {
                    return {
                        ok: false,
                        error: new Error(`return value ${JSON.stringify(value)} is not of type boolean`),
                    };
                }
                return { ok: true, value };
            }
            catch (error) {
                if ((0, jsGuard_1.isSyntax)(error)) {
                    return {
                        ok: false,
                        error: new logic_base_1.SourceSyntaxError(error),
                    };
                }
                if (error instanceof Error) {
                    return { ok: false, error };
                }
                const mapped = new Error(`unexpected error evaluating source`);
                // @ts-expect-error
                console.error(error.constructor.name, error.message);
                return {
                    ok: false,
                    error: mapped,
                };
            }
        },
    };
}
exports.JsImpl = JsImpl;
//# sourceMappingURL=jsImpl.js.map